package com.doc.biz.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

import com.doc.biz.domain.DocumentFile;
import com.doc.biz.service.IMongoService;
import com.doc.biz.vo.DocumentVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.enums.BusinessType;
import com.doc.biz.domain.DocInfo;
import com.doc.biz.service.IDocInfoService;
import com.doc.common.utils.poi.ExcelUtil;
import com.doc.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 文件基本信息表Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "文件基本信息表")
@RestController
@RequestMapping("/biz/info")
@Slf4j
public class DocInfoController extends BaseController {
    @Resource
    private IDocInfoService docInfoService;
    @Resource
    private IMongoService mongoService;

    /**
     * 文件上传
     *
     * @param file
     * @return
     */
    @ApiOperation("上传文件")
    @PostMapping("/upload")
    public AjaxResult uploadFile(@RequestParam(value = "file") MultipartFile file) {
        try {
            DocumentVO vo = mongoService.uploadFile(file);
            vo.getFileId();
            return success();
        } catch (Exception e) {
            log.error("文件上传失败：", e);
            return error(e.getMessage());
        }
    }

    /**
     * 多文件上传
     *
     * @param files
     * @return
     */
    @PostMapping("/uploadFiles")
    public AjaxResult uploadFile(@RequestParam(value = "files") List<MultipartFile> files) {
        try {
            return success(mongoService.uploadFiles(files));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 查询文件基本信息表列表
     */
    @ApiOperation("查询文件基本信息表列表")
    //@PreAuthorize("@ss.hasPermi('biz:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocInfo docInfo) {
        startPage();
        List<DocInfo> list = docInfoService.selectDocInfoList(docInfo);
        return getDataTable(list);
    }

    /**
     * 导出文件基本信息表列表
     */
    @ApiOperation("导出文件基本信息表列表")
    //@PreAuthorize("@ss.hasPermi('biz:info:export')")
    @Log(title = "文件基本信息表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocInfo docInfo) {
        List<DocInfo> list = docInfoService.selectDocInfoList(docInfo);
        ExcelUtil<DocInfo> util = new ExcelUtil<DocInfo>(DocInfo.class);
        util.exportExcel(response, list, "文件基本信息表数据");
    }

    /**
     * 获取文件基本信息表详细信息
     */
    @ApiOperation("获取文件基本信息表详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:info:query')")
    @GetMapping(value = "/{docId}")
    public AjaxResult getInfo(@PathVariable("docId") Long docId) {
        return success(docInfoService.selectDocInfoByDocId(docId));
    }

    /**
     * 新增文件基本信息表
     */
    @ApiOperation("新增文件基本信息表")
    //@PreAuthorize("@ss.hasPermi('biz:info:add')")
    @Log(title = "文件基本信息表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocInfo docInfo) {
        return toAjax(docInfoService.insertDocInfo(docInfo));
    }

    /**
     * 修改文件基本信息表
     */
    @ApiOperation("修改文件基本信息表")
    //@PreAuthorize("@ss.hasPermi('biz:info:edit')")
    @Log(title = "文件基本信息表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocInfo docInfo) {
        return toAjax(docInfoService.updateDocInfo(docInfo));
    }

    /**
     * 删除文件基本信息表
     */
    @ApiOperation("删除文件基本信息表")
    //@PreAuthorize("@ss.hasPermi('biz:info:remove')")
    @Log(title = "文件基本信息表", businessType = BusinessType.DELETE)
    @DeleteMapping("/{docIds}")
    public AjaxResult remove(@PathVariable Long[] docIds) {
        return toAjax(docInfoService.deleteDocInfoByDocIds(docIds));
    }
}
